crystal_toolkit.components.transformations.supercell module — Crystal Toolkit documentation

# crystal_toolkit.components.transformations.supercell module

class crystal_toolkit.components.transformations.supercell.SupercellTransformationComponent(input_structure_component_id: str, *args, **kwargs)

  Bases: `TransformationComponent`

  property description
  get_preview_layout(struct_in, struct_out)

    Override this method to give a layout that previews the transformation. Has beneficial side effect of priming the transformation cache when entire transformation pipeline is enabled.

    Parameters

      - struct_in – input Structure

      - struct_out – transformed Structure

    Returns

  options_layouts(state=None, structure=None)

    Return a layout to change the transformation options (that is, that controls the args and kwargs that will be passed to pymatgen).

    The “state” option is so that the controls can be populated appropriately using existing args and kwargs, e.g. when restoring the control panel from a previous state.

    Parameters

      state – existing state in format {“args”: [], “kwargs”: {}}

    Returns

  property title
  property transformation